@@ -4,10 +4,10 @@ from augraphy.augmentations.bleedthrough import BleedThrough
 from augraphy.augmentations.bookbinding import BookBinding
 from augraphy.augmentations.brightness import Brightness
 from augraphy.augmentations.brightnesstexturize import BrightnessTexturize
+from augraphy.augmentations.colorpaper import ColorPaper
 from augraphy.augmentations.dirtydrum import DirtyDrum
 from augraphy.augmentations.dirtyrollers import DirtyRollers
 from augraphy.augmentations.dithering import Dithering
-from augraphy.augmentations.dustyink import DustyInk
 from augraphy.augmentations.faxify import Faxify
 from augraphy.augmentations.folding import Folding
 from augraphy.augmentations.gamma import Gamma
@@ -16,7 +16,6 @@ from augraphy.augmentations.inkbleed import InkBleed
 from augraphy.augmentations.jpeg import Jpeg
 from augraphy.augmentations.letterpress import Letterpress
 from augraphy.augmentations.lightinggradient import LightingGradient
-from augraphy.augmentations.lowinkblobs import LowInkBlobs
 from augraphy.augmentations.lowinkperiodiclines import LowInkPeriodicLines
 from augraphy.augmentations.lowinkrandomlines import LowInkRandomLines
 from augraphy.augmentations.markup import Markup
@@ -24,6 +23,7 @@ from augraphy.augmentations.noisetexturize import NoiseTexturize
 from augraphy.augmentations.pageborder import PageBorder
 from augraphy.augmentations.pencilscribbles import PencilScribbles
 from augraphy.augmentations.subtlenoise import SubtleNoise
+from augraphy.augmentations.watermark import WaterMark
 
 
 __all__ = [
@@ -33,10 +33,10 @@ __all__ = [
     "BookBinding",
     "Brightness",
     "BrightnessTexturize",
+    "ColorPaper",
     "DirtyDrum",
     "DirtyRollers",
     "Dithering",
-    "DustyInk",
     "Faxify",
     "Folding",
     "Gamma",
@@ -45,7 +45,6 @@ __all__ = [
     "Jpeg",
     "Letterpress",
     "LightingGradient",
-    "LowInkBlobs",
     "LowInkPeriodicLines",
     "LowInkRandomLines",
     "Markup",
@@ -53,4 +52,5 @@ __all__ = [
     "PageBorder",
     "PencilScribbles",
     "SubtleNoise",
+    "WaterMark",
 ]
