@@ -1,9 +1,11 @@
+import os
 import random
+from glob import glob
 
 import cv2
 import numpy as np
-from PIL import Image
 
+from augraphy.augmentations.lib import generate_average_intensity
 from augraphy.augmentations.lib import sobel
 from augraphy.base.augmentation import Augmentation
 from augraphy.utilities import *
@@ -36,12 +38,12 @@ class BleedThrough(Augmentation):
 
     def __init__(
         self,
-        intensity_range=(0.1, 0.2),
+        intensity_range=(0.1, 0.9),
         color_range=(0, 224),
         ksize=(17, 17),
-        sigmaX=0,
-        alpha=0.3,
-        offsets=(10, 20),
+        sigmaX=1,
+        alpha=0.2,
+        offsets=(20, 20),
         p=1,
     ):
         super().__init__(p=p)
@@ -61,11 +63,29 @@ class BleedThrough(Augmentation):
 
         # convert to single channel to avoud unnecessary noise in colour image
         if len(img_bleed.shape) > 2:
-            img_bleed_input = cv2.cvtColor(img_bleed.astype("uint8"), cv2.COLOR_BGR2GRAY)
+            img_bleed_input = cv2.cvtColor(
+                img_bleed.astype("uint8"),
+                cv2.COLOR_BGR2GRAY,
+            )
         else:
             img_bleed_input = img_bleed.astype("uint8")
 
-        ob = OverlayBuilder("normal", img_bleed_input, img, 1, (1, 1), "center", 0, self.alpha)
+        # if the bleedthrough foreground is darker, reduce the blending alpha value
+        img_bleed_brightness = generate_average_intensity(img_bleed)
+        img_brightness = generate_average_intensity(img)
+        if img_bleed_brightness < img_brightness:
+            self.alpha *= (img_bleed_brightness / img_brightness) / 2
+
+        ob = OverlayBuilder(
+            "normal",
+            img_bleed_input,
+            img,
+            1,
+            (1, 1),
+            "center",
+            0,
+            self.alpha,
+        )
         return ob.build_overlay()
 
     # Offset image so that bleedthrough effect is visible and not stacked with input image
@@ -96,14 +116,51 @@ class BleedThrough(Augmentation):
         img_bleed = cv2.GaussianBlur(img_noise, ksize=ksize, sigmaX=sigmaX)
         return img_bleed
 
+    # create foreground image for bleedthrough effect
+    def create_bleedthrough_foreground(self, image):
+
+        # path to foreground cache folder
+        cache_folder_path = os.path.join(os.getcwd() + "/augraphy_cache/")
+        cache_image_paths = glob(cache_folder_path + "*.png", recursive=True)
+
+        # at least 2 images, because 1 image will be current image
+        if len(cache_image_paths) > 1:
+
+            modified_time = [os.path.getmtime(image_path) for image_path in cache_image_paths]
+            newest_index = np.argmax(modified_time)
+            image_index = random.randint(0, len(cache_image_paths) - 1)
+
+            # prevent same image
+            while image_index == newest_index:
+                image_index = random.randint(0, len(cache_image_paths) - 1)
+            # get random image
+            image_bleedthrough_foreground = cv2.imread(cache_image_paths[image_index])
+
+            # resize foreground
+            image_bleedthrough_foreground = cv2.resize(
+                image_bleedthrough_foreground,
+                (image.shape[1], image.shape[0]),
+                interpolation=cv2.INTER_AREA,
+            )
+            # flip left-right
+            image_bleedthrough_foreground = cv2.flip(image_bleedthrough_foreground, 1)
+
+        else:
+
+            # flip left-right only, flip top-bottom get inverted text, which is not realistic
+            image_bleedthrough_foreground = cv2.flip(image, 1)
+
+        return image_bleedthrough_foreground
+
     # Applies the Augmentation to input data.
     def __call__(self, image, layer=None, force=False):
         if force or self.should_run():
             image = image.copy()
-            image_flip = cv2.flip(image, 0)
-            image_flip = cv2.flip(image_flip, 1)
+
+            image_bleedthrough_foreground = self.create_bleedthrough_foreground(image)
+
             image_bleed = self.generate_bleeding_ink(
-                image_flip,
+                image_bleedthrough_foreground,
                 self.intensity_range,
                 self.color_range,
                 self.ksize,
